@@ -7,7 +7,7 @@ A library to perform aggregation functions.
 
 To suggest changes or submit new code please use the github page.
 """
-import Fancy_aggregations.tnorms as tnorms
+'''import Fancy_aggregations.tnorms as tnorms
 import Fancy_aggregations.integrals as integrals
 import Fancy_aggregations.implications as implications
 import Fancy_aggregations.intervals as intervals
@@ -17,4 +17,16 @@ import Fancy_aggregations.owas as owas
 import Fancy_aggregations.penalties as penalties
 import Fancy_aggregations.rankings as rankings
 import Fancy_aggregations.overlaps as overlaps
-import Fancy_aggregations.binary_parser as binary_parser
+import Fancy_aggregations.binary_parser as binary_parser'''
+
+from . import tnorms
+from . import integrals
+from . import implications
+from . import intervals
+from . import moderate_deviations
+from . import networks
+from . import owas
+from . import penalties
+from . import rankings
+from . import overlaps
+from . import binary_parser
\ No newline at end of file
